@@ -10,7 +10,8 @@ colpafs <- function(y, a) {
     d <- Rfast::vecdist(y[, i])
     fhat <- Rfast::rowmeans( exp( -0.5 * d^2 / h[i]^2 ) ) / sqrt(2 * pi) / h[i]
     fhata <- fhat^a
-    paf <- sum( fhata * d ) / n^2
+    #paf <- sum( fhata * d ) / n^2
+    paf <- sum( Rfast::eachcol.apply(d, fhata) ) / n^2
     alien <- mean(d)
     ident <- mean(fhata)
     rho <- paf / (alien * ident) - 1
